@@ -13,29 +13,40 @@ pub enum Error {
     /// itself fails. In that case no object exist to obtain the diagnostic record from.
     #[error("No Diagnostics available.")]
     NoDiagnostics,
-    #[error("{0}")]
     /// SQL Error had been returned by a low level ODBC function call. A Diagnostic record is
     /// obtained and associated with this error.
-    Diagnostics(DiagnosticRecord),
+    #[error("ODBC emitted an error calling '{function}':\n{record}")]
+    Diagnostics {
+        /// Diagnostic record returned by the ODBC driver manager
+        record: DiagnosticRecord,
+        /// ODBC API call which produced the diagnostic record
+        function: &'static str,
+    },
     /// A user dialog to complete the connection string has been aborted.
     #[error("The dialog shown to provide or complete the connection string has been aborted.")]
     AbortedConnectionStringCompletion,
+    /// An error returned if we fail to set the ODBC version
     #[error(
         "ODBC diver manager does not seem to support the required ODBC version 3.80. (Most
         likely you need to update unixODBC if you run on a Linux. Diagnostic record returned by
         SQLSetEnvAttr:\n{0}"
     )]
-    OdbcApiVersionUnsupported(DiagnosticRecord),
+    UnsupportedOdbcApiVersion(DiagnosticRecord),
+    /// An error emitted by an `std::io::ReadBuf` implementation used as an input argument.
     #[error("Sending data to the database at statement execution time failed. IO error:\n{0}")]
     FailedReadingInput(io::Error),
 }
 
 pub trait IntoResult {
-    fn into_result(self, handle: &dyn AsHandle) -> Result<(), Error>;
+    fn into_result(self, handle: &dyn AsHandle, function: &'static str) -> Result<(), Error>;
 }
 
 impl IntoResult for SqlReturn {
-    fn into_result(self: SqlReturn, handle: &dyn AsHandle) -> Result<(), Error> {
+    fn into_result(
+        self: SqlReturn,
+        handle: &dyn AsHandle,
+        function: &'static str,
+    ) -> Result<(), Error> {
         match self {
             // The function has been executed successfully. Holds result.
             SqlReturn::SUCCESS => Ok(()),
@@ -45,10 +56,10 @@ impl IntoResult for SqlReturn {
                 Ok(())
             }
             SqlReturn::ERROR => {
-                let mut rec = DiagnosticRecord::default();
-                if rec.fill_from(handle, 1) {
+                let mut record = DiagnosticRecord::default();
+                if record.fill_from(handle, 1) {
                     log_diagnostics(handle);
-                    Err(Error::Diagnostics(rec))
+                    Err(Error::Diagnostics { record, function })
                 } else {
                     Err(Error::NoDiagnostics)
                 }
