@@ -864,7 +864,7 @@ fn adaptive_columnar_insert_varchar(profile: &Profile) {
         Some(&b"Hello, World!"[..]),
     ];
 
-    let mut buffer = ColumnarRowSet::new(input.len() as u32, iter::once(desc));
+    let mut buffer = ColumnarRowSet::new(input.len(), iter::once(desc));
 
     buffer.set_num_rows(input.len());
     if let AnyColumnViewMut::Text(mut writer) = buffer.column_mut(0) {
@@ -917,7 +917,7 @@ fn adaptive_columnar_insert_varbin(profile: &Profile) {
         Some(&b"Hello, World!"[..]),
     ];
 
-    let mut buffer = ColumnarRowSet::new(input.len() as u32, iter::once(desc));
+    let mut buffer = ColumnarRowSet::new(input.len(), iter::once(desc));
 
     buffer.set_num_rows(input.len());
     if let AnyColumnViewMut::Binary(mut writer) = buffer.column_mut(0) {
@@ -1905,7 +1905,7 @@ fn large_strings(profile: &Profile) {
 
     loop {
         row.get_data(1, &mut buf).unwrap();
-        actual += &std::str::from_utf8(buf.as_bytes().unwrap()).unwrap();
+        actual += std::str::from_utf8(buf.as_bytes().unwrap()).unwrap();
         if buf.is_complete() {
             break;
         }
@@ -2600,13 +2600,7 @@ fn no_data(profile: &Profile) {
     let table_name = "NoData";
     let conn = profile.connection().unwrap();
 
-    setup_empty_table(
-        &conn,
-        profile.index_type,
-        table_name,
-        &["INTEGER"],
-    )
-    .unwrap();
+    setup_empty_table(&conn, profile.index_type, table_name, &["INTEGER"]).unwrap();
     let sql = format!("DELETE FROM {} WHERE id=5", table_name);
     // Assert no panic on direct execution
     conn.execute(&sql, ()).unwrap();
